<br>

<p align="center">
<img src="logo.png"  width="55%" />
</p>

<p align="center">
vue2-text-annotation
</p>

# Introduction
vue2-text-annotation is an easy-to-use component for text annotation and data masking. It achieves the features of locating, extracting and tagging entities in text. 

# 1. Text annotation

### Operation
1. Select or double click the content which you want to add an annotation to, then an input dialog will pop up.
2. Enter annotation content.
3. Click "ok" button or just press the enter key to accomplish the annotation.
4. If you want to remove an annoation, hover on annotation entity and click the delete button.

### Demo

<img src="./images/operation.gif"   />

[Online preview](https://yt6cc.csb.app/)

[![Edit on CodeSandbox](https://codesandbox.io/static/img/play-codesandbox.svg)](https://codesandbox.io/s/vue2-text-annotation-yt6cc?file=/src/App.vue)

### labeled data

```js
[
  {
    content:"Vue.js",
    category:"framework",
    start:0,
    end:6,
  },
  {
    content:"Evan You",
    category:"name",
    start:521,
    end:529,
  },
  {
    content:"JavaScript",
    category:"language",
    start:24,
    end:34,
  }
]
```
The labeled data generated by `vue2-text-annotation` can be used as the training data set of Natural Language Processing (NLP) model.

# Getting started
### Installation
```bash
npm install --save vue-manual-data-masking
```
### Usage
```js
<template>
  <TextAnnotation
    v-model="textAnnotations"
    :text="text"
  />
</template>

<script>
import TextAnnotation from "vue2-text-annotation";

export default {
  components: {
    TextAnnotation,
  },
  data() {
    return {
      text: "Vue.js is a progressive JavaScript framework, which is used to build UIs (User Interfaces) and SPAs (Single-page Applications). This framework is famous for its fast-paced learning curve. It is such an easy to learn and approachable library that with the knowledge of HTML, CSS, and JavaScript, we can start building web applications in Vue.js. The fast learning curve is kind of a signature of this framework. It is a versatile framework for our need as a library or a full-fledged framework for building huge web apps.\nEvan You have created this framework. The idea of Evan You behind this framework is to build the best framework by combining the best features from already existing Angular and react Frameworks. Before building Vue.js, Evan You was working at Google. Inc and worked on Angular based projects. So, he came up with the idea of building his own framework. He picked the best parts of Angular, like template syntax, easy to use, and picked the best parts of React as well, like two-way data binding, the concept of props, component-based approach, and combined them to make a new framework Vue.js better than both of them.",
      textAnnotations: [{
        content: "Vue.js",
        category: "framework",
        start:0,
        end:6,
      }]
    }
  }
};
```

# 2. Data masking
Data masking mode in `vue2-text-annotation` is used for labeling sensitive data and creating new text that hides (masks) sensitive information. 

### Demo
Before data masking: <br/>
<img src="./images/before-masking.png"  wight="150" /> <br/> <br/>
Data masking: <br/>
<img src="demo.gif"  wight="150" /> <br/><br/>
After data masking: <br/>
<img src="./images/after-masking.png"  wight="150" />

[![Edit on CodeSandbox](https://codesandbox.io/static/img/play-codesandbox.svg)](https://codesandbox.io/s/vue-manual-data-masking-yt6cc?file=/src/App.vue)


## Pops

| Property | Description | Type | Required | Default |
| -------- | ----------- | ---- | -------- | ------- |
| v-model | Bind to text annotations<br>e.g. <br>[{ content: "080080080", category: "phone number", start: 0, end: 5 }] | Annotation: <br>{<br>  content: string, <br>  category: string, <br>  start: number,<br>  end: number<br>} | true | [] |
| annotation-text-color | Font color of annotation entity | string | false |"#35495e" |
| annotation-bg-color | Background color of annotation entity | string | false | "#41b883"|
| data-masking | Set to `true` to start data masking mode | boolean | false | false |
| data-masking-charactor | Charactor in data masking entity| string | false | '●' |
| maxHeight | Max height of data masking container | Number or Null | false | null | |
| text | Text | String | true | '' |
| text-replace-charactor | Charactor be used to replace the sensitive data | string | false | '*" |



## Events
`afterDataMasking` event will be emitted when new sensitive data been masked. value of text after masking can be used inside of the callback function.

## Build Setup

```bash
# install dependencies
npm install
# serve with hot reload at localhost:8888
npm run serve
# build for production with minification
npm run build
```
